@@ -6,7 +6,7 @@ Inspired by http://djangosnippets.org/snippets/2463/
 """
 from django.contrib.auth.backends import ModelBackend
 from django.contrib.auth.models import User
-from django.core.validators import email_re
+from django.core.validators import validate_email
 
 
 class EmailBackend(ModelBackend):
@@ -20,7 +20,13 @@ class EmailBackend(ModelBackend):
     supports_inactive_user = False
 
     def authenticate(self, username=None, password=None):
-        if email_re.search(username):
+        try:
+            validate_email(username)
+        except:
+            username_is_email = False
+        else:
+            username_is_email = True
+        if username_is_email:
             try:
                 user = User.objects.get(email=username)
             except User.DoesNotExist:
